@@ -2,8 +2,12 @@
 {
   cat("\n")
   cat("-----------------------------------------------------------\n")
-  ver <- package.description("epi", lib = NULL, field="Version")
-  cat(paste("epi version", ver,  "is now loaded"))
+  ver <- packageDescription("epiR", lib.loc = NULL, fields = "Version")
+  cat(paste("epiR version", ver))
+  cat("\n")
+  cat("An R package for the analysis of epidemiological data.")
+  cat("\n")
+  cat("See http://epicentre.massey.ac.nz/ for details.")
   cat("\n")
   cat("-----------------------------------------------------------\n")
   invisible()
